@@ -19,7 +19,7 @@ from ansurr.functions import check_quiet_print
 from datetime import datetime
 
 sys.tracebacklimit = 0
-version = "0.0.29"
+version = "0.0.30"
 
 natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\d+)', s)]
 
@@ -72,7 +72,7 @@ def main():
         dssp.calc_secondary_structure(pdb,output_dir+'/other_output/dssp/',quiet=args.quiet)
 
     if args.welldef:
-        cyrange.calc_welldefined(path_to_pdb,output_dir,args.quiet)
+        args.welldef = cyrange.calc_welldefined(path_to_pdb,output_dir,args.quiet)
 
     check_quiet_print(args.quiet,'computing the flexibility of each model')
     chain_output_rigidity = {}
