@@ -83,9 +83,11 @@ def calc_welldefined(pdb,output_dir='',quiet=False):
             os.makedirs(output_dir+'/other_output/cyrange/')
         with open(output_dir+'/other_output/cyrange/cyrange.json', 'w') as outfile:
             json.dump(cyrange, outfile)
+        return True
 
     else:
         check_quiet_print(quiet," -> ERROR CYRANGE failed to identify well-defined residues")
+        return False
 
 def main():
 
