@@ -13,6 +13,10 @@ def calc_secondary_structure(pdb,output_dir='',quiet=False):
         with resources.path("ansurr.bin", "dssp.bin") as f:  # use this for the package
         #with resources.path("bin", "dssp.bin") as f: 
             dssp_file_path = f
+    elif platform == "darwin":
+        with resources.path("ansurr.bin", "dsspOSX.bin") as f:  # use this for the package
+            dssp_file_path = f
+
 
     if not os.path.exists(output_dir):
         os.makedirs(output_dir)
